==> enschin-0.1.0.crate: enschin-0.1.0/src/graphics/vertex.rs <==
use std::mem;

use crate::{
    Vec2
};


use wgpu::{
    VertexBufferLayout,
    VertexStepMode,
    BufferAddress,
    VertexAttribute,
    VertexFormat
};

#[derive(Copy, Clone)]
pub struct Vertex {
    pos: Vec2<f32>,
    tex_coords: Vec2<f32>
}


impl Vertex {

    pub fn new(x: f32, y: f32, tcx: f32, tcy: f32) -> Self {
        Vertex {
            pos: Vec2::new(x, y),
            tex_coords: Vec2::new(tcx, tcy)
        }
    }

    pub const fn desc<'a>() -> VertexBufferLayout<'a> {
        VertexBufferLayout {
            array_stride: mem::size_of::<Self>() as BufferAddress,
            step_mode: VertexStepMode::Vertex,
            attributes: &[
                VertexAttribute {
                    offset: 0,
                    shader_location: 0,
                    format: VertexFormat::Float32x2,
                },
                VertexAttribute {
                    offset: mem::size_of::<[f32; 2]>() as BufferAddress,
                    shader_location: 1,
                    format: VertexFormat::Float32x2, // NEW!
                },
            ]
        }
    }

    pub const fn instance_desc<'a>() -> VertexBufferLayout<'a> {
        wgpu::VertexBufferLayout {
            array_stride: mem::size_of::<[f32; 16]>() as wgpu::BufferAddress,
            step_mode: wgpu::VertexStepMode::Instance,
            attributes: &[
                wgpu::VertexAttribute {
                    offset: 0,
                    shader_location: 5,
                    format: wgpu::VertexFormat::Float32x4,
                },
                wgpu::VertexAttribute {
                    offset: mem::size_of::<[f32; 4]>() as wgpu::BufferAddress,
                    shader_location: 6,
                    format: wgpu::VertexFormat::Float32x4,
                },
                wgpu::VertexAttribute {
                    offset: mem::size_of::<[f32; 8]>() as wgpu::BufferAddress,
                    shader_location: 7,
                    format: wgpu::VertexFormat::Float32x4,
                },
                wgpu::VertexAttribute {
                    offset: mem::size_of::<[f32; 12]>() as wgpu::BufferAddress,
                    shader_location: 8,
                    format: wgpu::VertexFormat::Float32x4,
                },
            ],
        }
    }
}

unsafe impl bytemuck::Pod for Vertex {}
unsafe impl bytemuck::Zeroable for Vertex {}

==> enschin-0.1.1.crate: enschin-0.1.1/src/graphics/vertex.rs <==
use std::mem;

use crate::{
    Vec2
};


use wgpu::{
    VertexBufferLayout,
    VertexStepMode,
    BufferAddress,
    VertexAttribute,
    VertexFormat
};

#[derive(Copy, Clone)]
pub struct Vertex {
    _pos: Vec2<f32>,
    _tex_coords: Vec2<f32>
}


impl Vertex {

    pub fn new(x: f32, y: f32, tcx: f32, tcy: f32) -> Self {
        Vertex {
            _pos: Vec2::new(x, y),
            _tex_coords: Vec2::new(tcx, tcy)
        }
    }

    pub const fn desc<'a>() -> VertexBufferLayout<'a> {
        VertexBufferLayout {
            array_stride: mem::size_of::<Self>() as BufferAddress,
            step_mode: VertexStepMode::Vertex,
            attributes: &[
                VertexAttribute {
                    offset: 0,
                    shader_location: 0,
                    format: VertexFormat::Float32x2,
                },
                VertexAttribute {
                    offset: mem::size_of::<[f32; 2]>() as BufferAddress,
                    shader_location: 1,
                    format: VertexFormat::Float32x2, // NEW!
                },
            ]
        }
    }

    pub const fn instance_desc<'a>() -> VertexBufferLayout<'a> {
        wgpu::VertexBufferLayout {
            array_stride: mem::size_of::<[f32; 16]>() as wgpu::BufferAddress,
            step_mode: wgpu::VertexStepMode::Instance,
            attributes: &[
                wgpu::VertexAttribute {
                    offset: 0,
                    shader_location: 5,
                    format: wgpu::VertexFormat::Float32x4,
                },
                wgpu::VertexAttribute {
                    offset: mem::size_of::<[f32; 4]>() as wgpu::BufferAddress,
                    shader_location: 6,
                    format: wgpu::VertexFormat::Float32x4,
                },
                wgpu::VertexAttribute {
                    offset: mem::size_of::<[f32; 8]>() as wgpu::BufferAddress,
                    shader_location: 7,
                    format: wgpu::VertexFormat::Float32x4,
                },
                wgpu::VertexAttribute {
                    offset: mem::size_of::<[f32; 12]>() as wgpu::BufferAddress,
                    shader_location: 8,
                    format: wgpu::VertexFormat::Float32x4,
                },
            ],
        }
    }
}

unsafe impl bytemuck::Pod for Vertex {}
unsafe impl bytemuck::Zeroable for Vertex {}
